from cumin.objectframe import ObjectFrame

from hadoop import *
from hadoopobjectframe import *
from cumin.objectselector import ObjectTable

from jobtracker import JobTrackerFrame, JobTrackerSelector
from namenode import NameNodeFrame, NameNodeSelector

class HadoopSchedulerAdapter(HadoopAdapter):
    def get_sage_results(self, values):
        owner_filter = self.get_owner_filter(values['session'])
        results = self.app.remote.get_hosts("SCHEDULER", "HADOOP")
        return results

    def do_get_data(self, values):
        data = self.get_sage_results(values)
        if data is None or len(data) == 0:
            return {}
        return data

    def process_record(self, key, record):
        field_data = list()
        for column in self.columns:
            val = record
            field_data.append(val)
        return field_data

class HadoopSchedulerSelector(ObjectSelector):
    def __init__(self, app, name, check_owner=False):
        cls = app.model.com_redhat_cumin_grid_hadoop.Scheduler

        super(HadoopSchedulerSelector, self).__init__(app, name, cls)

        self.table.adapter = HadoopSchedulerAdapter(app, cls)
        self.add_search_filter(self.table.id_col)

        self.enable_csv_export()

    def create_table(self, app, name, cls):
        return HadoopSchedulerTable(app, name, cls)

    def render_title(self, session):
        return "Schedulers"

class HadoopSchedulerTable(ObjectTable):
    def __init__(self, app, name, cls):
        super(HadoopSchedulerTable, self).__init__(app, name, cls)

        self.id_col = self.SchedNameColumn(app, "namecol", cls.Name, cls.Name, ".ghschedframe")
        self.add_column(self.id_col)

    def get_data_values(self, session):
        values = super(HadoopSchedulerTable, self).get_data_values(session)
        values['session'] = session
        return values

    def get_data_options(self, session):
        options = super(HadoopSchedulerTable, self).get_data_options(session)
        options.like_specs = self.like_specs
        return options

    class SchedNameColumn(ObjectLinkColumn):
        def render_cell_href(self, session, record):
            id = unescape_entity(record[self.id_field.index])
            frame = self.frame.children_by_name[self.frame.name + self.frame_path]
            return frame.get_href(session, id, id)



class HadoopSchedulerFrame(HadoopObjectFrame):
    def __init__(self, app, name, check_owner, module):
        super(HadoopSchedulerFrame, self).__init__(app, name, module)

        self.name_node_frame = NameNodeFrame(app, name + ".namenodeframe", self.module)
        self.add_mode(self.name_node_frame)

        self.job_tracker_frame = JobTrackerFrame(app, name + ".jobtrackerframe", self.module)
        self.add_mode(self.job_tracker_frame)

        self.view.add_tab(NameNodeSelector(app, name + ".namenodes", self.module, check_owner))
        self.view.add_tab(JobTrackerSelector(app, name + ".jobtrackers", self.module, check_owner))

    def get_object(self, session, id):
        class Object(object):
            pass
        sched = Object()
        sched.Name = id
        sched.Id = id
        return sched

    def get_title(self, session):
        retval = ""
        try:
            retval = "Hadoop scheduler:'%s'" % (xml_escape(self.object.get(session).Name))
        except Exception, e:
            pass
        return retval
