import logging
from cumin.module import CuminModule
from wooly.util import StringCatalog

strings = StringCatalog(__file__)

from cumin.gridhadoop import GridHadoopFrame

log = logging.getLogger("cumin")

class Module(CuminModule):
    def __init__(self, app, name):
        super(Module, self).__init__(app, name)

    def init(self):
        super(Module, self).init()
    
        # This module (user.hadoop) requires that the "user" module has been 
        # imported and initialized with a call to user.Module()
        # CuminModule classes will add themselves to "app" as an attribute
        # during intialization so we can use that to check...
        if hasattr(self.app, "user") and self.app.user:
            self.frame = GridHadoopFrame(self.app, "userhadoop", self, check_owner=True)
            self.frame.cumin_module = self.name
            self.app.user.add_to_view(self.frame)
        else:
            msg = "Module %s requires that the 'user' module be imported and"\
                      " initialized." % self.name
            log.error(msg)
            raise Exception(msg)

            
